@@ -1,19 +1,20 @@
 """
 Type annotations for codeguruprofiler service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators/)
 
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_codeguruprofiler import CodeGuruProfilerClient
+    from mypy_boto3_codeguruprofiler.client import CodeGuruProfilerClient
     from mypy_boto3_codeguruprofiler.paginator import (
         ListProfileTimesPaginator,
     )
 
-    client: CodeGuruProfilerClient = boto3.client("codeguruprofiler")
+    session = Session()
+    client: CodeGuruProfilerClient = session.client("codeguruprofiler")
 
     list_profile_times_paginator: ListProfileTimesPaginator = client.get_paginator("list_profile_times")
     ```
@@ -21,8 +22,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import AggregationPeriodType, OrderByType
 from .type_defs import ListProfileTimesResponseTypeDef, PaginatorConfigTypeDef
@@ -40,10 +40,10 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListProfileTimesPaginator(Boto3Paginator):
+class ListProfileTimesPaginator(Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators/#listprofiletimespaginator)
     """
 
     def paginate(
@@ -57,6 +57,6 @@ class ListProfileTimesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListProfileTimesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators/#listprofiletimespaginator)
         """
