@@ -1,14 +1,14 @@
 """
 Type annotations for codeguruprofiler service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/type_defs/)
 
 Usage::
 
     ```python
-    from mypy_boto3_codeguruprofiler.type_defs import AddNotificationChannelsRequestRequestTypeDef
+    from mypy_boto3_codeguruprofiler.type_defs import ChannelTypeDef
 
-    data: AddNotificationChannelsRequestRequestTypeDef = {...}
+    data: ChannelTypeDef = {...}
     ```
 """
 import sys
@@ -37,83 +37,99 @@ else:
 
 
 __all__ = (
-    "AddNotificationChannelsRequestRequestTypeDef",
-    "AddNotificationChannelsResponseTypeDef",
+    "ChannelTypeDef",
+    "ResponseMetadataTypeDef",
     "AgentConfigurationTypeDef",
     "AgentOrchestrationConfigTypeDef",
     "AggregatedProfileTimeTypeDef",
-    "AnomalyInstanceTypeDef",
-    "AnomalyTypeDef",
-    "BatchGetFrameMetricDataRequestRequestTypeDef",
-    "BatchGetFrameMetricDataResponseTypeDef",
-    "ChannelTypeDef",
+    "UserFeedbackTypeDef",
+    "MetricTypeDef",
+    "FrameMetricTypeDef",
+    "TimestampStructureTypeDef",
     "ConfigureAgentRequestRequestTypeDef",
-    "ConfigureAgentResponseTypeDef",
-    "CreateProfilingGroupRequestRequestTypeDef",
-    "CreateProfilingGroupResponseTypeDef",
     "DeleteProfilingGroupRequestRequestTypeDef",
     "DescribeProfilingGroupRequestRequestTypeDef",
-    "DescribeProfilingGroupResponseTypeDef",
     "FindingsReportSummaryTypeDef",
-    "FrameMetricDatumTypeDef",
-    "FrameMetricTypeDef",
     "GetFindingsReportAccountSummaryRequestRequestTypeDef",
-    "GetFindingsReportAccountSummaryResponseTypeDef",
     "GetNotificationConfigurationRequestRequestTypeDef",
-    "GetNotificationConfigurationResponseTypeDef",
     "GetPolicyRequestRequestTypeDef",
-    "GetPolicyResponseTypeDef",
     "GetProfileRequestRequestTypeDef",
-    "GetProfileResponseTypeDef",
     "GetRecommendationsRequestRequestTypeDef",
-    "GetRecommendationsResponseTypeDef",
     "ListFindingsReportsRequestRequestTypeDef",
-    "ListFindingsReportsResponseTypeDef",
-    "ListProfileTimesRequestRequestTypeDef",
-    "ListProfileTimesResponseTypeDef",
-    "ListProfilingGroupsRequestRequestTypeDef",
-    "ListProfilingGroupsResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "MatchTypeDef",
-    "MetricTypeDef",
-    "NotificationConfigurationTypeDef",
     "PaginatorConfigTypeDef",
+    "ListProfileTimesRequestRequestTypeDef",
+    "ProfileTimeTypeDef",
+    "ListProfilingGroupsRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "MatchTypeDef",
     "PatternTypeDef",
     "PostAgentProfileRequestRequestTypeDef",
-    "ProfileTimeTypeDef",
-    "ProfilingGroupDescriptionTypeDef",
-    "ProfilingStatusTypeDef",
     "PutPermissionRequestRequestTypeDef",
-    "PutPermissionResponseTypeDef",
-    "RecommendationTypeDef",
     "RemoveNotificationChannelRequestRequestTypeDef",
-    "RemoveNotificationChannelResponseTypeDef",
     "RemovePermissionRequestRequestTypeDef",
-    "RemovePermissionResponseTypeDef",
-    "ResponseMetadataTypeDef",
     "SubmitFeedbackRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
-    "TimestampStructureTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "AddNotificationChannelsRequestRequestTypeDef",
+    "NotificationConfigurationTypeDef",
+    "GetPolicyResponseTypeDef",
+    "GetProfileResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "PutPermissionResponseTypeDef",
+    "RemovePermissionResponseTypeDef",
+    "ConfigureAgentResponseTypeDef",
+    "CreateProfilingGroupRequestRequestTypeDef",
     "UpdateProfilingGroupRequestRequestTypeDef",
+    "ProfilingStatusTypeDef",
+    "AnomalyInstanceTypeDef",
+    "BatchGetFrameMetricDataRequestRequestTypeDef",
+    "FrameMetricDatumTypeDef",
+    "GetFindingsReportAccountSummaryResponseTypeDef",
+    "ListFindingsReportsResponseTypeDef",
+    "ListProfileTimesRequestListProfileTimesPaginateTypeDef",
+    "ListProfileTimesResponseTypeDef",
+    "RecommendationTypeDef",
+    "AddNotificationChannelsResponseTypeDef",
+    "GetNotificationConfigurationResponseTypeDef",
+    "RemoveNotificationChannelResponseTypeDef",
+    "ProfilingGroupDescriptionTypeDef",
+    "AnomalyTypeDef",
+    "BatchGetFrameMetricDataResponseTypeDef",
+    "CreateProfilingGroupResponseTypeDef",
+    "DescribeProfilingGroupResponseTypeDef",
+    "ListProfilingGroupsResponseTypeDef",
     "UpdateProfilingGroupResponseTypeDef",
-    "UserFeedbackTypeDef",
+    "GetRecommendationsResponseTypeDef",
 )
 
-AddNotificationChannelsRequestRequestTypeDef = TypedDict(
-    "AddNotificationChannelsRequestRequestTypeDef",
+_RequiredChannelTypeDef = TypedDict(
+    "_RequiredChannelTypeDef",
     {
-        "channels": Sequence["ChannelTypeDef"],
-        "profilingGroupName": str,
+        "eventPublishers": Sequence[Literal["AnomalyDetection"]],
+        "uri": str,
     },
 )
-
-AddNotificationChannelsResponseTypeDef = TypedDict(
-    "AddNotificationChannelsResponseTypeDef",
+_OptionalChannelTypeDef = TypedDict(
+    "_OptionalChannelTypeDef",
     {
-        "notificationConfiguration": "NotificationConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "id": str,
+    },
+    total=False,
+)
+
+
+class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
+    pass
+
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -155,95 +171,38 @@ AggregatedProfileTimeTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredAnomalyInstanceTypeDef = TypedDict(
-    "_RequiredAnomalyInstanceTypeDef",
+UserFeedbackTypeDef = TypedDict(
+    "UserFeedbackTypeDef",
     {
-        "id": str,
-        "startTime": datetime,
-    },
-)
-_OptionalAnomalyInstanceTypeDef = TypedDict(
-    "_OptionalAnomalyInstanceTypeDef",
-    {
-        "endTime": datetime,
-        "userFeedback": "UserFeedbackTypeDef",
-    },
-    total=False,
-)
-
-
-class AnomalyInstanceTypeDef(_RequiredAnomalyInstanceTypeDef, _OptionalAnomalyInstanceTypeDef):
-    pass
-
-
-AnomalyTypeDef = TypedDict(
-    "AnomalyTypeDef",
-    {
-        "instances": List["AnomalyInstanceTypeDef"],
-        "metric": "MetricTypeDef",
-        "reason": str,
+        "type": FeedbackTypeType,
     },
 )
 
-_RequiredBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchGetFrameMetricDataRequestRequestTypeDef",
+MetricTypeDef = TypedDict(
+    "MetricTypeDef",
     {
-        "profilingGroupName": str,
-    },
-)
-_OptionalBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchGetFrameMetricDataRequestRequestTypeDef",
-    {
-        "endTime": Union[datetime, str],
-        "frameMetrics": Sequence["FrameMetricTypeDef"],
-        "period": str,
-        "startTime": Union[datetime, str],
-        "targetResolution": AggregationPeriodType,
-    },
-    total=False,
-)
-
-
-class BatchGetFrameMetricDataRequestRequestTypeDef(
-    _RequiredBatchGetFrameMetricDataRequestRequestTypeDef,
-    _OptionalBatchGetFrameMetricDataRequestRequestTypeDef,
-):
-    pass
-
-
-BatchGetFrameMetricDataResponseTypeDef = TypedDict(
-    "BatchGetFrameMetricDataResponseTypeDef",
-    {
-        "endTime": datetime,
-        "endTimes": List["TimestampStructureTypeDef"],
-        "frameMetricData": List["FrameMetricDatumTypeDef"],
-        "resolution": AggregationPeriodType,
-        "startTime": datetime,
-        "unprocessedEndTimes": Dict[str, List["TimestampStructureTypeDef"]],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "frameName": str,
+        "threadStates": List[str],
+        "type": Literal["AggregatedRelativeTotalTime"],
     },
 )
 
-_RequiredChannelTypeDef = TypedDict(
-    "_RequiredChannelTypeDef",
+FrameMetricTypeDef = TypedDict(
+    "FrameMetricTypeDef",
     {
-        "eventPublishers": Sequence[Literal["AnomalyDetection"]],
-        "uri": str,
+        "frameName": str,
+        "threadStates": Sequence[str],
+        "type": Literal["AggregatedRelativeTotalTime"],
     },
 )
-_OptionalChannelTypeDef = TypedDict(
-    "_OptionalChannelTypeDef",
+
+TimestampStructureTypeDef = TypedDict(
+    "TimestampStructureTypeDef",
     {
-        "id": str,
+        "value": datetime,
     },
-    total=False,
 )
 
-
-class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
-    pass
-
-
 _RequiredConfigureAgentRequestRequestTypeDef = TypedDict(
     "_RequiredConfigureAgentRequestRequestTypeDef",
     {
@@ -266,47 +225,6 @@ class ConfigureAgentRequestRequestTypeDef(
     pass
 
 
-ConfigureAgentResponseTypeDef = TypedDict(
-    "ConfigureAgentResponseTypeDef",
-    {
-        "configuration": "AgentConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateProfilingGroupRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateProfilingGroupRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "profilingGroupName": str,
-    },
-)
-_OptionalCreateProfilingGroupRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateProfilingGroupRequestRequestTypeDef",
-    {
-        "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
-        "computePlatform": ComputePlatformType,
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateProfilingGroupRequestRequestTypeDef(
-    _RequiredCreateProfilingGroupRequestRequestTypeDef,
-    _OptionalCreateProfilingGroupRequestRequestTypeDef,
-):
-    pass
-
-
-CreateProfilingGroupResponseTypeDef = TypedDict(
-    "CreateProfilingGroupResponseTypeDef",
-    {
-        "profilingGroup": "ProfilingGroupDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeleteProfilingGroupRequestRequestTypeDef = TypedDict(
     "DeleteProfilingGroupRequestRequestTypeDef",
     {
@@ -321,14 +239,6 @@ DescribeProfilingGroupRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeProfilingGroupResponseTypeDef = TypedDict(
-    "DescribeProfilingGroupResponseTypeDef",
-    {
-        "profilingGroup": "ProfilingGroupDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 FindingsReportSummaryTypeDef = TypedDict(
     "FindingsReportSummaryTypeDef",
     {
@@ -341,23 +251,6 @@ FindingsReportSummaryTypeDef = TypedDict(
     total=False,
 )
 
-FrameMetricDatumTypeDef = TypedDict(
-    "FrameMetricDatumTypeDef",
-    {
-        "frameMetric": "FrameMetricTypeDef",
-        "values": List[float],
-    },
-)
-
-FrameMetricTypeDef = TypedDict(
-    "FrameMetricTypeDef",
-    {
-        "frameName": str,
-        "threadStates": Sequence[str],
-        "type": Literal["AggregatedRelativeTotalTime"],
-    },
-)
-
 GetFindingsReportAccountSummaryRequestRequestTypeDef = TypedDict(
     "GetFindingsReportAccountSummaryRequestRequestTypeDef",
     {
@@ -368,15 +261,6 @@ GetFindingsReportAccountSummaryRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetFindingsReportAccountSummaryResponseTypeDef = TypedDict(
-    "GetFindingsReportAccountSummaryResponseTypeDef",
-    {
-        "nextToken": str,
-        "reportSummaries": List["FindingsReportSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetNotificationConfigurationRequestRequestTypeDef = TypedDict(
     "GetNotificationConfigurationRequestRequestTypeDef",
     {
@@ -384,14 +268,6 @@ GetNotificationConfigurationRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetNotificationConfigurationResponseTypeDef = TypedDict(
-    "GetNotificationConfigurationResponseTypeDef",
-    {
-        "notificationConfiguration": "NotificationConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetPolicyRequestRequestTypeDef = TypedDict(
     "GetPolicyRequestRequestTypeDef",
     {
@@ -399,15 +275,6 @@ GetPolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetPolicyResponseTypeDef = TypedDict(
-    "GetPolicyResponseTypeDef",
-    {
-        "policy": str,
-        "revisionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetProfileRequestRequestTypeDef = TypedDict(
     "_RequiredGetProfileRequestRequestTypeDef",
     {
@@ -433,16 +300,6 @@ class GetProfileRequestRequestTypeDef(
     pass
 
 
-GetProfileResponseTypeDef = TypedDict(
-    "GetProfileResponseTypeDef",
-    {
-        "contentEncoding": str,
-        "contentType": str,
-        "profile": StreamingBody,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetRecommendationsRequestRequestTypeDef = TypedDict(
     "_RequiredGetRecommendationsRequestRequestTypeDef",
     {
@@ -467,18 +324,6 @@ class GetRecommendationsRequestRequestTypeDef(
     pass
 
 
-GetRecommendationsResponseTypeDef = TypedDict(
-    "GetRecommendationsResponseTypeDef",
-    {
-        "anomalies": List["AnomalyTypeDef"],
-        "profileEndTime": datetime,
-        "profileStartTime": datetime,
-        "profilingGroupName": str,
-        "recommendations": List["RecommendationTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListFindingsReportsRequestRequestTypeDef = TypedDict(
     "_RequiredListFindingsReportsRequestRequestTypeDef",
     {
@@ -505,13 +350,14 @@ class ListFindingsReportsRequestRequestTypeDef(
     pass
 
 
-ListFindingsReportsResponseTypeDef = TypedDict(
-    "ListFindingsReportsResponseTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "findingsReportSummaries": List["FindingsReportSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 _RequiredListProfileTimesRequestRequestTypeDef = TypedDict(
@@ -540,13 +386,12 @@ class ListProfileTimesRequestRequestTypeDef(
     pass
 
 
-ListProfileTimesResponseTypeDef = TypedDict(
-    "ListProfileTimesResponseTypeDef",
+ProfileTimeTypeDef = TypedDict(
+    "ProfileTimeTypeDef",
     {
-        "nextToken": str,
-        "profileTimes": List["ProfileTimeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "start": datetime,
     },
+    total=False,
 )
 
 ListProfilingGroupsRequestRequestTypeDef = TypedDict(
@@ -559,16 +404,6 @@ ListProfilingGroupsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListProfilingGroupsResponseTypeDef = TypedDict(
-    "ListProfilingGroupsResponseTypeDef",
-    {
-        "nextToken": str,
-        "profilingGroupNames": List[str],
-        "profilingGroups": List["ProfilingGroupDescriptionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -576,14 +411,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 MatchTypeDef = TypedDict(
     "MatchTypeDef",
     {
@@ -594,33 +421,6 @@ MatchTypeDef = TypedDict(
     total=False,
 )
 
-MetricTypeDef = TypedDict(
-    "MetricTypeDef",
-    {
-        "frameName": str,
-        "threadStates": List[str],
-        "type": Literal["AggregatedRelativeTotalTime"],
-    },
-)
-
-NotificationConfigurationTypeDef = TypedDict(
-    "NotificationConfigurationTypeDef",
-    {
-        "channels": List["ChannelTypeDef"],
-    },
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
 PatternTypeDef = TypedDict(
     "PatternTypeDef",
     {
@@ -638,7 +438,7 @@ PatternTypeDef = TypedDict(
 _RequiredPostAgentProfileRequestRequestTypeDef = TypedDict(
     "_RequiredPostAgentProfileRequestRequestTypeDef",
     {
-        "agentProfile": Union[bytes, IO[bytes], StreamingBody],
+        "agentProfile": Union[str, bytes, IO[Any], StreamingBody],
         "contentType": str,
         "profilingGroupName": str,
     },
@@ -658,39 +458,6 @@ class PostAgentProfileRequestRequestTypeDef(
     pass
 
 
-ProfileTimeTypeDef = TypedDict(
-    "ProfileTimeTypeDef",
-    {
-        "start": datetime,
-    },
-    total=False,
-)
-
-ProfilingGroupDescriptionTypeDef = TypedDict(
-    "ProfilingGroupDescriptionTypeDef",
-    {
-        "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
-        "arn": str,
-        "computePlatform": ComputePlatformType,
-        "createdAt": datetime,
-        "name": str,
-        "profilingStatus": "ProfilingStatusTypeDef",
-        "tags": Dict[str, str],
-        "updatedAt": datetime,
-    },
-    total=False,
-)
-
-ProfilingStatusTypeDef = TypedDict(
-    "ProfilingStatusTypeDef",
-    {
-        "latestAgentOrchestratedAt": datetime,
-        "latestAgentProfileReportedAt": datetime,
-        "latestAggregatedProfile": "AggregatedProfileTimeTypeDef",
-    },
-    total=False,
-)
-
 _RequiredPutPermissionRequestRequestTypeDef = TypedDict(
     "_RequiredPutPermissionRequestRequestTypeDef",
     {
@@ -714,27 +481,6 @@ class PutPermissionRequestRequestTypeDef(
     pass
 
 
-PutPermissionResponseTypeDef = TypedDict(
-    "PutPermissionResponseTypeDef",
-    {
-        "policy": str,
-        "revisionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-RecommendationTypeDef = TypedDict(
-    "RecommendationTypeDef",
-    {
-        "allMatchesCount": int,
-        "allMatchesSum": float,
-        "endTime": datetime,
-        "pattern": "PatternTypeDef",
-        "startTime": datetime,
-        "topMatches": List["MatchTypeDef"],
-    },
-)
-
 RemoveNotificationChannelRequestRequestTypeDef = TypedDict(
     "RemoveNotificationChannelRequestRequestTypeDef",
     {
@@ -743,14 +489,6 @@ RemoveNotificationChannelRequestRequestTypeDef = TypedDict(
     },
 )
 
-RemoveNotificationChannelResponseTypeDef = TypedDict(
-    "RemoveNotificationChannelResponseTypeDef",
-    {
-        "notificationConfiguration": "NotificationConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 RemovePermissionRequestRequestTypeDef = TypedDict(
     "RemovePermissionRequestRequestTypeDef",
     {
@@ -760,26 +498,6 @@ RemovePermissionRequestRequestTypeDef = TypedDict(
     },
 )
 
-RemovePermissionResponseTypeDef = TypedDict(
-    "RemovePermissionResponseTypeDef",
-    {
-        "policy": str,
-        "revisionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
-        "RetryAttempts": int,
-    },
-)
-
 _RequiredSubmitFeedbackRequestRequestTypeDef = TypedDict(
     "_RequiredSubmitFeedbackRequestRequestTypeDef",
     {
@@ -811,13 +529,6 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-TimestampStructureTypeDef = TypedDict(
-    "TimestampStructureTypeDef",
-    {
-        "value": datetime,
-    },
-)
-
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -826,25 +537,341 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+AddNotificationChannelsRequestRequestTypeDef = TypedDict(
+    "AddNotificationChannelsRequestRequestTypeDef",
+    {
+        "channels": Sequence[ChannelTypeDef],
+        "profilingGroupName": str,
+    },
+)
+
+NotificationConfigurationTypeDef = TypedDict(
+    "NotificationConfigurationTypeDef",
+    {
+        "channels": List[ChannelTypeDef],
+    },
+    total=False,
+)
+
+GetPolicyResponseTypeDef = TypedDict(
+    "GetPolicyResponseTypeDef",
+    {
+        "policy": str,
+        "revisionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetProfileResponseTypeDef = TypedDict(
+    "GetProfileResponseTypeDef",
+    {
+        "contentEncoding": str,
+        "contentType": str,
+        "profile": StreamingBody,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutPermissionResponseTypeDef = TypedDict(
+    "PutPermissionResponseTypeDef",
+    {
+        "policy": str,
+        "revisionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RemovePermissionResponseTypeDef = TypedDict(
+    "RemovePermissionResponseTypeDef",
+    {
+        "policy": str,
+        "revisionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ConfigureAgentResponseTypeDef = TypedDict(
+    "ConfigureAgentResponseTypeDef",
+    {
+        "configuration": AgentConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateProfilingGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProfilingGroupRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "profilingGroupName": str,
+    },
+)
+_OptionalCreateProfilingGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProfilingGroupRequestRequestTypeDef",
+    {
+        "agentOrchestrationConfig": AgentOrchestrationConfigTypeDef,
+        "computePlatform": ComputePlatformType,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateProfilingGroupRequestRequestTypeDef(
+    _RequiredCreateProfilingGroupRequestRequestTypeDef,
+    _OptionalCreateProfilingGroupRequestRequestTypeDef,
+):
+    pass
+
+
 UpdateProfilingGroupRequestRequestTypeDef = TypedDict(
     "UpdateProfilingGroupRequestRequestTypeDef",
     {
-        "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
+        "agentOrchestrationConfig": AgentOrchestrationConfigTypeDef,
         "profilingGroupName": str,
     },
 )
 
+ProfilingStatusTypeDef = TypedDict(
+    "ProfilingStatusTypeDef",
+    {
+        "latestAgentOrchestratedAt": datetime,
+        "latestAgentProfileReportedAt": datetime,
+        "latestAggregatedProfile": AggregatedProfileTimeTypeDef,
+    },
+    total=False,
+)
+
+_RequiredAnomalyInstanceTypeDef = TypedDict(
+    "_RequiredAnomalyInstanceTypeDef",
+    {
+        "id": str,
+        "startTime": datetime,
+    },
+)
+_OptionalAnomalyInstanceTypeDef = TypedDict(
+    "_OptionalAnomalyInstanceTypeDef",
+    {
+        "endTime": datetime,
+        "userFeedback": UserFeedbackTypeDef,
+    },
+    total=False,
+)
+
+
+class AnomalyInstanceTypeDef(_RequiredAnomalyInstanceTypeDef, _OptionalAnomalyInstanceTypeDef):
+    pass
+
+
+_RequiredBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchGetFrameMetricDataRequestRequestTypeDef",
+    {
+        "profilingGroupName": str,
+    },
+)
+_OptionalBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchGetFrameMetricDataRequestRequestTypeDef",
+    {
+        "endTime": Union[datetime, str],
+        "frameMetrics": Sequence[FrameMetricTypeDef],
+        "period": str,
+        "startTime": Union[datetime, str],
+        "targetResolution": AggregationPeriodType,
+    },
+    total=False,
+)
+
+
+class BatchGetFrameMetricDataRequestRequestTypeDef(
+    _RequiredBatchGetFrameMetricDataRequestRequestTypeDef,
+    _OptionalBatchGetFrameMetricDataRequestRequestTypeDef,
+):
+    pass
+
+
+FrameMetricDatumTypeDef = TypedDict(
+    "FrameMetricDatumTypeDef",
+    {
+        "frameMetric": FrameMetricTypeDef,
+        "values": List[float],
+    },
+)
+
+GetFindingsReportAccountSummaryResponseTypeDef = TypedDict(
+    "GetFindingsReportAccountSummaryResponseTypeDef",
+    {
+        "nextToken": str,
+        "reportSummaries": List[FindingsReportSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListFindingsReportsResponseTypeDef = TypedDict(
+    "ListFindingsReportsResponseTypeDef",
+    {
+        "findingsReportSummaries": List[FindingsReportSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredListProfileTimesRequestListProfileTimesPaginateTypeDef = TypedDict(
+    "_RequiredListProfileTimesRequestListProfileTimesPaginateTypeDef",
+    {
+        "endTime": Union[datetime, str],
+        "period": AggregationPeriodType,
+        "profilingGroupName": str,
+        "startTime": Union[datetime, str],
+    },
+)
+_OptionalListProfileTimesRequestListProfileTimesPaginateTypeDef = TypedDict(
+    "_OptionalListProfileTimesRequestListProfileTimesPaginateTypeDef",
+    {
+        "orderBy": OrderByType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListProfileTimesRequestListProfileTimesPaginateTypeDef(
+    _RequiredListProfileTimesRequestListProfileTimesPaginateTypeDef,
+    _OptionalListProfileTimesRequestListProfileTimesPaginateTypeDef,
+):
+    pass
+
+
+ListProfileTimesResponseTypeDef = TypedDict(
+    "ListProfileTimesResponseTypeDef",
+    {
+        "nextToken": str,
+        "profileTimes": List[ProfileTimeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RecommendationTypeDef = TypedDict(
+    "RecommendationTypeDef",
+    {
+        "allMatchesCount": int,
+        "allMatchesSum": float,
+        "endTime": datetime,
+        "pattern": PatternTypeDef,
+        "startTime": datetime,
+        "topMatches": List[MatchTypeDef],
+    },
+)
+
+AddNotificationChannelsResponseTypeDef = TypedDict(
+    "AddNotificationChannelsResponseTypeDef",
+    {
+        "notificationConfiguration": NotificationConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetNotificationConfigurationResponseTypeDef = TypedDict(
+    "GetNotificationConfigurationResponseTypeDef",
+    {
+        "notificationConfiguration": NotificationConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RemoveNotificationChannelResponseTypeDef = TypedDict(
+    "RemoveNotificationChannelResponseTypeDef",
+    {
+        "notificationConfiguration": NotificationConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ProfilingGroupDescriptionTypeDef = TypedDict(
+    "ProfilingGroupDescriptionTypeDef",
+    {
+        "agentOrchestrationConfig": AgentOrchestrationConfigTypeDef,
+        "arn": str,
+        "computePlatform": ComputePlatformType,
+        "createdAt": datetime,
+        "name": str,
+        "profilingStatus": ProfilingStatusTypeDef,
+        "tags": Dict[str, str],
+        "updatedAt": datetime,
+    },
+    total=False,
+)
+
+AnomalyTypeDef = TypedDict(
+    "AnomalyTypeDef",
+    {
+        "instances": List[AnomalyInstanceTypeDef],
+        "metric": MetricTypeDef,
+        "reason": str,
+    },
+)
+
+BatchGetFrameMetricDataResponseTypeDef = TypedDict(
+    "BatchGetFrameMetricDataResponseTypeDef",
+    {
+        "endTime": datetime,
+        "endTimes": List[TimestampStructureTypeDef],
+        "frameMetricData": List[FrameMetricDatumTypeDef],
+        "resolution": AggregationPeriodType,
+        "startTime": datetime,
+        "unprocessedEndTimes": Dict[str, List[TimestampStructureTypeDef]],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateProfilingGroupResponseTypeDef = TypedDict(
+    "CreateProfilingGroupResponseTypeDef",
+    {
+        "profilingGroup": ProfilingGroupDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeProfilingGroupResponseTypeDef = TypedDict(
+    "DescribeProfilingGroupResponseTypeDef",
+    {
+        "profilingGroup": ProfilingGroupDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListProfilingGroupsResponseTypeDef = TypedDict(
+    "ListProfilingGroupsResponseTypeDef",
+    {
+        "nextToken": str,
+        "profilingGroupNames": List[str],
+        "profilingGroups": List[ProfilingGroupDescriptionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateProfilingGroupResponseTypeDef = TypedDict(
     "UpdateProfilingGroupResponseTypeDef",
     {
-        "profilingGroup": "ProfilingGroupDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "profilingGroup": ProfilingGroupDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-UserFeedbackTypeDef = TypedDict(
-    "UserFeedbackTypeDef",
+GetRecommendationsResponseTypeDef = TypedDict(
+    "GetRecommendationsResponseTypeDef",
     {
-        "type": FeedbackTypeType,
+        "anomalies": List[AnomalyTypeDef],
+        "profileEndTime": datetime,
+        "profileStartTime": datetime,
+        "profilingGroupName": str,
+        "recommendations": List[RecommendationTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
